@@ -6,8 +6,10 @@ from .transaction import TransactionFactory
 from .unit_of_work import UnitOfWork
 from .utils import (
     changeset,
+    count_versions,
     get_versioning_manager,
     is_modified,
+    is_session_modified,
     parent_class,
     transaction_class,
     tx_column_name,
@@ -16,7 +18,7 @@ from .utils import (
 )
 
 
-__version__ = '1.0.3'
+__version__ = '1.1.0'
 
 
 versioning_manager = VersioningManager()
@@ -67,6 +69,12 @@ def make_versioned(
         'before_cursor_execute',
         manager.track_association_operations
     )
+    if manager.options['native_versioning']:
+        sa.event.listen(
+            sa.pool.Pool,
+            'connect',
+            manager.on_connect
+        )
 
 
 def remove_versioning(
@@ -94,3 +102,9 @@ def remove_versioning(
         'before_cursor_execute',
         manager.track_association_operations
     )
+    if manager.options['native_versioning']:
+        sa.event.remove(
+            sa.pool.Pool,
+            'connect',
+            manager.on_connect
+        )
