@@ -8,6 +8,11 @@ import six
 import sqlalchemy as sa
 from sqlalchemy.ext.compiler import compiles
 
+from .dialects.postgresql import (
+    CreateTemporaryTransactionTableSQL,
+    InsertTemporaryTransactionSQL,
+    TransactionTriggerSQL
+)
 from .exc import ImproperlyConfigured
 from .factory import ModelFactory
 
@@ -18,7 +23,6 @@ def compile_big_integer(element, compiler, **kw):
 
 
 class TransactionBase(object):
-    id = sa.Column(sa.types.BigInteger, primary_key=True, autoincrement=True)
     issued_at = sa.Column(sa.DateTime, default=datetime.utcnow)
 
     @property
@@ -56,6 +60,48 @@ class TransactionBase(object):
         return entities
 
 
+procedure_sql = """
+CREATE OR REPLACE FUNCTION transaction_temp_table_generator()
+RETURNS TRIGGER AS $$
+BEGIN
+    {temporary_transaction_sql}
+    INSERT INTO temporary_transaction (id) VALUES (NEW.id);
+    RETURN NEW;
+END;
+$$
+LANGUAGE plpgsql
+"""
+
+
+def create_triggers(cls):
+    sa.event.listen(
+        cls.__table__,
+        'after_create',
+        sa.schema.DDL(
+            procedure_sql.format(
+                temporary_transaction_sql=CreateTemporaryTransactionTableSQL(),
+                insert_temporary_transaction_sql=(
+                    InsertTemporaryTransactionSQL(
+                        transaction_id_values='NEW.id'
+                    )
+                ),
+            )
+        )
+    )
+    sa.event.listen(
+        cls.__table__,
+        'after_create',
+        sa.schema.DDL(str(TransactionTriggerSQL(cls)))
+    )
+    sa.event.listen(
+        cls.__table__,
+        'after_drop',
+        sa.schema.DDL(
+            'DROP FUNCTION IF EXISTS transaction_temp_table_generator()'
+        )
+    )
+
+
 class TransactionFactory(ModelFactory):
     model_name = 'Transaction'
 
@@ -73,6 +119,12 @@ class TransactionFactory(ModelFactory):
             __tablename__ = 'transaction'
             __versioning_manager__ = manager
 
+            id = sa.Column(
+                sa.types.BigInteger,
+                primary_key=True,
+                autoincrement=True
+            )
+
             if self.remote_addr:
                 remote_addr = sa.Column(sa.String(50))
 
@@ -118,4 +170,7 @@ class TransactionFactory(ModelFactory):
                         for field, value in field_values.items()
                     )
                 )
+
+        if manager.options['native_versioning']:
+            create_triggers(Transaction)
         return Transaction
